@@ -12,8 +12,11 @@ def download_raw_data(
     forecast_type: str,
     tables: Union[str, List[str]],
     raw_cache: str,
+    keep_csv: bool = False,
 ) -> None:
-    """Downloads raw forecast data from NEMWeb
+    """Downloads raw forecast data from NEMWeb MMSDM Historical Data SQLLoader
+
+    Downloads raw forecast data and converts to parquet.
 
     Arguments:
         forecast_start: Forecasts made at or after this datetime are queried.
@@ -21,7 +24,7 @@ def download_raw_data(
         forecasted_start: Forecasts pertaining to times at or after this
             datetime are retained.
         forecasted_end: Forecasts pertaining to times before or at this
-            datetime are retaned.
+            datetime are retained.
         forecast_type: `MTPASA`, `STPASA`, `PDPASA`, `PREDISPATCH` or `P5MIN`.
         tables: Table or tables required. A single table can be supplied as
             a string. Multiple tables can be supplied as a list of strings.
@@ -36,5 +39,9 @@ def download_raw_data(
         tables=tables,
         raw_cache=raw_cache,
     )
-    downloader = ForecastTypeDownloader.from_Loader(loader)
-    downloader.download_zip()
+    if loader.check_data_in_cache():
+        pass
+    else:
+        downloader = ForecastTypeDownloader.from_Loader(loader)
+        downloader.download_csv()
+        downloader.convert_to_parquet(keep_csv=keep_csv)
